@@ -25,9 +25,7 @@
 /* need a way to configure and save this data, if this header is to
  * be installed.  For now, dont install it */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "evolution-ews-config.h"
 
 #ifdef ENABLE_THREADS
 #define CAMEL_EWS_FOLDER_LOCK(f, l) \
