@@ -190,6 +190,8 @@ const gchar *	e_ews_item_get_date_header	(EEwsItem *item);
 time_t		e_ews_item_get_date_received	(EEwsItem *item);
 time_t		e_ews_item_get_date_sent	(EEwsItem *item);
 time_t		e_ews_item_get_date_created	(EEwsItem *item);
+time_t		e_ews_item_get_last_modified_time
+						(EEwsItem *item);
 gboolean	e_ews_item_has_attachments	(EEwsItem *item,
 						 gboolean *has_attachments);
 gboolean	e_ews_item_is_read		(EEwsItem *item,
@@ -216,6 +218,8 @@ EwsMailbox *
 void		e_ews_mailbox_free		(EwsMailbox *mailbox);
 
 gboolean	e_ews_item_get_is_meeting	(EEwsItem *item);
+gboolean	e_ews_item_get_is_response_requested
+						(EEwsItem *item);
 const GSList *	e_ews_item_get_modified_occurrences
 						(EEwsItem *item);
 gchar *		e_ews_embed_attachment_id_in_uri (const gchar *olduri, const gchar *attach_id);
