@@ -1,11 +1,22 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "evolution-ews-config.h"
 
 #include <libedataserver/eds-version.h>
 
@@ -96,6 +107,7 @@ e_soap_response_new (void)
 /**
  * e_soap_response_new_from_string:
  * @xmlstr: the XML string to parse.
+ * @xmlstr_len: XML string's length or -1 for a null-terminated string
  *
  * Create a new #ESoapResponse object from the XML string contained
  * in @xmlstr.
@@ -104,14 +116,15 @@ e_soap_response_new (void)
  * error).
  */
 ESoapResponse *
-e_soap_response_new_from_string (const gchar *xmlstr)
+e_soap_response_new_from_string (const gchar *xmlstr,
+				 gint xmlstr_length)
 {
 	ESoapResponse *response;
 
 	g_return_val_if_fail (xmlstr != NULL, NULL);
 
 	response = g_object_new (E_TYPE_SOAP_RESPONSE, NULL);
-	if (!e_soap_response_from_string (response, xmlstr)) {
+	if (!e_soap_response_from_string (response, xmlstr, xmlstr_length)) {
 		g_object_unref (response);
 		return NULL;
 	}
@@ -169,6 +182,7 @@ parse_parameters (ESoapResponse *response,
  * e_soap_response_from_string:
  * @response: the #ESoapResponse object.
  * @xmlstr: XML string to parse.
+ * @xmlstr_len: XML string's length or -1 for a null-terminated string
  *
  * Parses the string contained in @xmlstr and sets all properties from
  * it in the @response object.
@@ -177,7 +191,8 @@ parse_parameters (ESoapResponse *response,
  */
 gboolean
 e_soap_response_from_string (ESoapResponse *response,
-                             const gchar *xmlstr)
+                             const gchar *xmlstr,
+			     gint xmlstr_length)
 {
 	xmlDocPtr xmldoc;
 
@@ -185,7 +200,7 @@ e_soap_response_from_string (ESoapResponse *response,
 	g_return_val_if_fail (xmlstr != NULL, FALSE);
 
 	/* parse the string */
-	xmldoc = xmlParseMemory (xmlstr, strlen (xmlstr));
+	xmldoc = xmlParseMemory (xmlstr, xmlstr_length == -1 ? strlen (xmlstr) : xmlstr_length);
 	if (!xmldoc)
 		return FALSE;
 
